---
title: Websites powered by Urubu
layout: simple_page
---

I created Urubu to solve a personal problem: how to create and maintain
websites for my projects. I open-sourced it "in the hope it can be useful".  On
this page I list a number of websites that are powered by Urubu.

By others
=========

[Sigasi Insights][sigasi] - Documentation for Sigasi's tools. 

For others, by me
=================

[Vlaamse sofrologen][sofro] - Site of the flemish sophrologists (in Dutch)

[Troca Vins Naturels][troca] - Natural wines

MyHDL
=====

[myhdl_site] - all about MyHDL, for users

[dev_myhdl_site] - info for MyHDL developers

Urubu
=====

[urubu-quickstart] - the Quickstart companion site for Urubu

[urubu] - this site 

Personal
========

[Jan Decaluwe][jan] My site about professional activities

[Jan Decaluwe / Music][janmusic] My music projects

[Jan Decaluwe / Opinions][janopinion] My opinions, in Dutch


[sigasi]: http://doc.sigasi.com
[sofro]: http://www.vlaamsesofrologen.be
[jan]: http://www.jandecaluwe.com
[janmusic]: http://music.jandecaluwe.com
[janopinion]: http://nl.jandecaluwe.com
[troca]: http://www.troca-vn.be
